@@ -1,8 +1,8 @@
-"""Main module for the geodemo package."""
+"""Main module for the nclpy package."""
 import os
 import ipyleaflet
 from ipyleaflet import FullScreenControl, LayersControl, DrawControl, MeasureControl, ScaleControl, TileLayer
-# from .utils import random_string
+from .utils import random_string
 
 class Map(ipyleaflet.Map):
     """This Map class inherits the ipyleaflet Map class.
